[−][src]Enum argon2::Variant
The Argon2 variant.
Variants
Argon2dArgon2 using data-dependent memory access to thwart tradeoff attacks. Recommended for cryptocurrencies and backend servers.
Argon2iArgon2 using data-independent memory access to thwart side-channel attacks. Recommended for password hashing and password-based key derivation.
Argon2idArgon2 using hybrid construction.
Methods
impl Variant[src]
impl Variantpub fn as_lowercase_str(&self) -> &'static str[src]
pub fn as_lowercase_str(&self) -> &'static strGets the lowercase string slice representation of the variant.
pub fn as_u32(&self) -> u32[src]
pub fn as_u32(&self) -> u32Gets the u32 representation of the variant.
pub fn as_u64(&self) -> u64[src]
pub fn as_u64(&self) -> u64Gets the u64 representation of the variant.
pub fn as_uppercase_str(&self) -> &'static str[src]
pub fn as_uppercase_str(&self) -> &'static strGets the uppercase string slice representation of the variant.
pub fn from_str(str: &str) -> Result<Variant>[src]
pub fn from_str(str: &str) -> Result<Variant>Attempts to create a variant from a string slice.
pub fn from_u32(val: u32) -> Result<Variant>[src]
pub fn from_u32(val: u32) -> Result<Variant>Attempts to create a variant from an u32.